Python: module get_request

get_request (version 0.0.1) | index scripts\request\get_request.py

`This package implements a web server to run scripts or
executables from the command line and display the result
in a web interface.
This file prints a user request.`

Modules
`` |  |
sys |  |  |

Data
`` |  | __all__ = [] __author_email__ = 'mauricelambert434@gmail.com' __copyright__ = '\nWebScripts Copyright (C) 2021 Maurice Lambert...ome to redistribute it\nunder certain conditions.\n' __description__ = 'This package implements a web server to run scri...a web interface.\n\nThis file prints a user request' __license__ = 'GPL-3.0 License' __maintainer__ = 'Maurice Lambert' __maintainer_email__ = 'mauricelambert434@gmail.com' __url__ = 'https://github.com/mauricelambert/WebScripts'

Author
`` |  | Maurice Lambert